@@ -86,7 +86,7 @@ SOFTWARE.
         创建文件，生成一些必要的字段，只需要填写对应的字段值，无需关心
         """
         with open(f"{self.project_folder_path}/setup.py", "w", encoding="utf-8") as fp, \
-                open('create_packet/setup_template.py', "r", encoding="utf-8") as fh:
+                open(f'{os.getcwd()}/setup_template.py', "r", encoding="utf-8") as fh:
             fp.write(fh.read())
 
     def _create_packet_folder(self):
